@@ -28,7 +28,7 @@ pub struct Args {
     #[clap(
         long = "font",
         short = 'f',
-        help = "弹幕使用字体",
+        help = "弹幕使用字体。单位：像素",
         default_value = "黑体"
     )]
     font: String,
@@ -37,13 +37,20 @@ pub struct Args {
     font_size: u32,
 
     #[clap(
-        long = "font-ratio",
         long = "width-ratio",
-        help = "为避免重叠需要调大这个数值，即“水平间距”",
+        help = "计算弹幕宽度的比例，为避免重叠可以调大这个数值",
         default_value = "1.2"
     )]
     width_ratio: f64,
 
+    #[clap(
+        long = "horizontal-gap",
+        help = "每条弹幕之间的最小水平间距，为避免重叠可以调大这个数值。单位：像素",
+        default_value = "20.0"
+    )]
+    #[serde(default)]
+    horizontal_gap: f64,
+
     #[clap(
         long = "duration",
         short = 'd',
@@ -97,6 +104,14 @@ pub struct Args {
     #[clap(long = "bold", help = "加粗")]
     #[serde(default)]
     pub bold: bool,
+
+    #[clap(
+        long = "time-offset",
+        help = "时间轴偏移，>0 会让弹幕延后，<0 会让弹幕提前，单位为秒",
+        default_value = "0.0"
+    )]
+    #[serde(default)]
+    pub time_offset: f64,
 }
 
 impl Args {
@@ -123,6 +138,7 @@ impl Args {
             font: self.font.clone(),
             font_size: self.font_size,
             width_ratio: self.width_ratio,
+            horizontal_gap: self.horizontal_gap,
             duration: self.duration,
             lane_size: self.lane_size,
             float_percentage: self.float_percentage,
@@ -130,6 +146,7 @@ impl Args {
             bottom_percentage: 0.3,
             outline: self.outline,
             bold: if self.bold { 1 } else { 0 },
+            time_offset: self.time_offset,
         }
     }
 
@@ -138,7 +155,13 @@ impl Args {
             None => Ok(None),
             Some(path) => {
                 let denylist = std::fs::read_to_string(path)?;
-                let list = denylist.split('\n').map(|s| s.trim().to_string()).collect();
+                let list: HashSet<String> = denylist
+                    .split('\n')
+                    .map(|s| s.trim().to_string())
+                    .filter(|s| !s.is_empty())
+                    .collect();
+                log::info!("黑名单载入 {} 个", list.len());
+                log::debug!("黑名单：{:?}", list);
                 Ok(Some(list))
             }
         }
