@@ -1,4 +1,5 @@
 //! 一个弹幕实例，但是没有位置信息
+use super::CanvasConfig;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum DanmuType {
@@ -23,8 +24,18 @@ pub struct Danmu {
 }
 
 impl Danmu {
-    /// 像素长度
-    pub fn length(&self) -> u32 {
-        self.fontsize * self.content.chars().count() as u32
+    /// 计算弹幕的“像素长度”，会乘上一个缩放因子
+    ///
+    /// 汉字算一个全宽，英文算2/3宽
+    pub fn length(&self, config: &CanvasConfig) -> f64 {
+        let pts = self.fontsize
+            * self
+                .content
+                .chars()
+                .map(|ch| if ch.is_ascii() { 2 } else { 3 })
+                .sum::<u32>()
+            / 3;
+
+        pts as f64 * config.width_ratio
     }
 }
